@@ -29,13 +29,13 @@ eb = Earlybyte()
 @app.command()
 def mission():
     """Show the mission statement of Earlybyte."""
-    typer.echo(eb.mission)
+    typer.secho(eb.mission, fg=typer.colors.BRIGHT_MAGENTA)
 
 
 @app.command()
 def vision():
     """Show the vision statement of Earlybyte."""
-    typer.echo(eb.vision)
+    typer.secho(eb.vision, fg=typer.colors.BRIGHT_MAGENTA)
 
 
 @app.command()
@@ -48,10 +48,10 @@ def values(
 
     if index is not None:
         if 0 <= index and index <= 4:
-            typer.echo(eb.values[index])
+            typer.secho(eb.values[index], fg=typer.colors.BRIGHT_MAGENTA)
             return
 
-    typer.echo(eb.values)
+    typer.secho(", ".join(eb.values), fg=typer.colors.BRIGHT_MAGENTA)
 
 
 def main():
